@@ -1,4 +1,4 @@
-<?PHP //$Id: delete.php,v 1.13.4.2 2008/05/02 04:07:27 dongsheng Exp $
+<?php
 
 // Deletes the moodledata directory, COMPLETELY!!
 // BE VERY CAREFUL USING THIS!
@@ -17,27 +17,32 @@
 
     $deletedir = $CFG->dataroot;   // The directory to delete!
 
-    admin_externalpage_print_header();
-    print_heading('Purge moodledata');
+    echo $OUTPUT->header();
+    echo $OUTPUT->heading('Purge moodledata');
 
     if (empty($sure)) {
         $optionsyes = array('sure'=>'yes', 'sesskey'=>sesskey());
-        notice_yesno ('Are you completely sure you want to delete everything inside the directory '. $deletedir .' ?',
-            'delete.php', 'index.php', $optionsyes, NULL, 'post', 'get');
-        admin_externalpage_print_footer();
+
+        $formcontinue = new single_button(new moodle_url('delete.php', $optionsyes), get_string('yes'));
+        $formcancel = new single_button('index.php', get_string('no'), 'get');
+        echo $OUTPUT->confirm('Are you completely sure you want to delete everything inside the directory '. $deletedir .' ?', $formcontinue, $formcancel);
+        echo $OUTPUT->footer();
         exit;
     }
 
     if (!data_submitted() or empty($reallysure)) {
         $optionsyes = array('sure'=>'yes', 'sesskey'=>sesskey(), 'reallysure'=>'yes');
-        notice_yesno ('Are you REALLY REALLY completely sure you want to delete everything inside the directory '. $deletedir .' (this includes all user images, and any other course files that have been created) ?',
-            'delete.php', 'index.php', $optionsyes, NULL, 'post', 'get');
-        admin_externalpage_print_footer();
+        $formcontinue = new single_button(new moodle_url('delete.php', $optionsyes), get_string('yes'));
+        $formcancel = new single_button('index.php', get_string('no'), 'get');
+        echo $OUTPUT->confirm('Are you REALLY REALLY completely sure you want to delete everything inside the directory '.
+                $deletedir .' (this includes all user images, and any other course files that have been created) ?',
+                $formcontinue, $formcancel);
+        echo $OUTPUT->footer();
         exit;
     }
 
     if (!confirm_sesskey()) {
-        error('This script was called wrongly');
+        print_error('wrongcall', 'error');
     }
 
     /// OK, here goes ...
@@ -45,8 +50,8 @@
     delete_subdirectories($deletedir);
 
     echo '<h1 align="center">Done!</h1>';
-    print_continue($CFG->wwwroot);
-    admin_externalpage_print_footer();
+    echo $OUTPUT->continue_button($CFG->wwwroot);
+    echo $OUTPUT->footer();
     exit;
 
 
@@ -78,4 +83,4 @@ function delete_subdirectories($rootdir) {
     closedir($dir);
 }
 
-?>
+
