@@ -1,12 +1,12 @@
-<?php // $Id: version.php,v 1.29.2.9 2010/10/05 01:56:10 jerome Exp $
+<?php
 
 ////////////////////////////////////////////////////////////////////////////////
 //  Code fragment to define the module version etc.
 //  This fragment is called by /admin/index.php
 ////////////////////////////////////////////////////////////////////////////////
 
-$module->version  = 2007101515;
-$module->requires = 2007101509;  // Requires this Moodle version
+$module->version  = 2011052300;
+$module->requires = 2011052300;  // Requires this Moodle version
 $module->cron     = 60;
 
-?>
+
