@@ -1,12 +1,12 @@
-<?php // $Id: version.php,v 1.31.2.2 2008/03/03 12:02:12 moodler Exp $
+<?php
 
 ////////////////////////////////////////////////////////////////////////////////
 //  Code fragment to define the module version etc.
 //  This fragment is called by /admin/index.php
 ////////////////////////////////////////////////////////////////////////////////
 
-$module->version  = 2007101509;
-$module->requires = 2007101509;  // Requires this Moodle version
+$module->version  = 2010080300;
+$module->requires = 2010080300;  // Requires this Moodle version
 $module->cron     = 0;
 
-?>
+
